@@ -1,6 +1,7 @@
 import os.path
 import subprocess
 import importlib.util
+import sys
 
 
 def _get_py_hook_type(hook_type: str) -> None | str:
@@ -21,11 +22,21 @@ def _execute_python_hook(hook_type: str):
     foo = importlib.util.module_from_spec(spec)
     spec.loader.exec_module(foo)
 
-    if hasattr(foo, 'hook'):
-        foo.hook()
-    else:
+    if not hasattr(foo, 'hook'):
         print('Invalid python git hook. Must have "hook" function to run.')
 
+    try:
+        res = foo.hook()
+
+        if res is not None and not res:
+            print(f"Failure indicated by hook function in {hook_type}.py via return value. Aborting.")
+            sys.exit(1)
+
+    except Exception as e:
+        print(f"Exception encountered in hook {hook_type}.py. Aborting.")
+        print(e)
+        sys.exit(1)
+
 
 def run_hook(hook: str):
     hook_type = _get_py_hook_type(hook)
